@@ -74,7 +74,7 @@ function CR.init(env)
     local auto_delimiter = env.settings.auto_delimiter
     local is_pro = wanxiang.is_pro_scheme(env)
     -- 根据方案选择加载路径
-    local path = (is_pro and "dicts/corrections.pro.dict.yaml") or "dicts/corrections.dict.yaml"
+    local path = (is_pro and "dicts/cuoyin.pro.dict.yaml") or "dicts/cuoyin.dict.yaml"
     local file, close_file, err = wanxiang.load_file_with_fallback(path)
     if not file then
         log.error(string.format("[super_comment]: 加载失败 %s，错误: %s", path, err))
@@ -210,140 +210,129 @@ local function get_fz_comment(cand, env, initial_comment)
         return ""
     end
 end
--- ----------------------
--- # 自动无词频造词模块
--- ----------------------
-local AP = {}
-local comment_cache = {}
 
-function AP.init(env)
-    local config = env.engine.schema.config
-    local enable_auto_phrase = config:get_bool("add_user_dict/enable_auto_phrase") or false
-    local enable_user_dict = config:get_bool("add_user_dict/enable_user_dict") or false
 
-        -- 依据配置选择是否开始缓存comment
-    if enable_auto_phrase and enable_user_dict then 
-        env.memory = Memory(env.engine, env.engine.schema, "add_user_dict")
-        env._commit_conn = env.engine.context.commit_notifier:connect(
-            function(ctx)
-                AP.commit_handler(ctx, env)
-            end
-        )
-        env._delete_conn = env.engine.context.delete_notifier:connect(
-            function(ctx)
-                comment_cache = {}
-            end
-        )
+local SV = {}
+
+-- 工具：取光标前的编码（安全处理 caret 越界）
+local function front_input(ctx)
+    if not ctx then return "" end
+    local raw_full = ctx.input or ""
+    local caret    = ctx.caret_pos or #raw_full
+    if caret < 0 then
+        caret = 0
+    elseif caret > #raw_full then
+        caret = #raw_full
     end
+    return raw_full:sub(1, caret)
 end
 
-function AP.fini(env)
-    if env._commit_conn then
-        env._commit_conn:disconnect()
-        env._commit_conn = nil
-    end
+-- 这个模块主要用于将滤镜阶段未修改前的注释或者 preedit
+-- 存到上下文变量里，按键处理阶段使用；update_notifier 保证一致性
+function SV.init(env)
+    env._sv_seq_sig          = ""
+    env._sv_last_pre         = ""   -- 最近一次要写入的 preedit
+    env._saved_input_for_seq = ""   -- 上次对应的 raw_in（光标前编码）
 
-    if env._delete_conn then
-        env._delete_conn:disconnect()
-        env._delete_conn = nil
-    end
+    local ctx = env.engine.context
 
-    if env.memory then
-        env.memory:disconnect()
-        env.memory = nil
-    end
+    env._sv_ctx_conn = ctx.update_notifier:connect(function(c)
+        local raw_in = front_input(c)
+
+        local pre = env._sv_last_pre or ""
+        if pre == "" or raw_in == "" then
+            return
+        end
+
+        -- 不重写：光标前编码 + preedit
+        local sig = raw_in .. "\t" .. pre
+        if env._sv_seq_sig == sig then
+            return
+        end
+
+        c:set_property("sequence_preedit_key", raw_in)
+        c:set_property("sequence_preedit_val", pre)
+        env._sv_seq_sig = sig
+    end)
 end
 
-function AP.save_comment_cache(cand)
-    local comment = cand.comment
-    local comment_text = cand.text
-
-    if comment_text and comment_text ~= "" and comment and comment ~= "" then
-        comment_cache[comment_text] = comment
+-- 断开 notifier，清理状态
+function SV.fini(env)
+    if env._sv_ctx_conn then
+        env._sv_ctx_conn:disconnect()
+        env._sv_ctx_conn = nil
     end
+    env._sv_seq_sig          = nil
+    env._sv_last_pre         = nil
+    env._saved_input_for_seq = nil
 end
 
-function AP.commit_handler(ctx, env)
-    if not ctx or not ctx.composition then
-        comment_cache = {}
+-- 限制更新范围：同一个 raw_in 只记第一次的 preedit
+function SV.update_preedit(env, preedit)
+    local ctx = env.engine.context
+    if not ctx then return end
+
+    local raw_in = front_input(ctx)
+    preedit = preedit or ""
+
+    if raw_in == "" or preedit == "" then
         return
     end
 
-    local segments = ctx.composition:toSegmentation():get_segments()
-    local segments_count = #segments
-    local commit_text = ctx:get_commit_text()
-
-    -- 检查是否符合最小造词单元要求
-    if segments_count <= 1 or utf8.len(commit_text) <= 1 then
-        comment_cache = {}
+    if env._saved_input_for_seq ~= raw_in then
+        env._saved_input_for_seq = raw_in
+        env._sv_last_pre         = preedit
+    end
+end
+-- 对 cand.preedit 应用 tone_preedit/0..9 的映射（数字 -> 上标等）
+local function apply_tone_preedit(env, cand)
+    if not cand or not cand.preedit or cand.preedit == "" then
         return
     end
 
-    -- 检查是否符合造词内容要求
-    if not AP.is_chinese_only(commit_text) or comment_cache[commit_text] then
-        comment_cache = {}
+    -- 用 context.input 判断是否有相邻数字
+    local input
+    local engine = env.engine
+    if engine and engine.context then
+        -- Rime 里一般是 string，保险起见兜个 nil
+        input = engine.context.input or ""
+    end
+
+    -- 如果整条输入串中存在相邻两个数字（例如 "li39"、"abc10" 等），
+    -- 则整体不做任何转换，直接返回，为了配合小键盘输入逻辑中包吃书字面大小一致性
+    if input and input ~= "" and input:match("%d%d") then
         return
     end
 
-    local preedits_table = {}
-    local config = env.engine.schema.config
-    local delimiter = config:get_string("speller/delimiter") or " '"
-    local escaped_delimiter = utf8.char(utf8.codepoint(delimiter)):gsub("(%W)", "%%%1")
-
-    for i = 1, segments_count do
-        local seg = segments[i]
-        local cand = seg:get_selected_candidate()
-
-        if cand then
-            local cand_text = cand.text
-            local preedit = comment_cache[cand_text]
-
-            if preedit and preedit ~= "" then
-                for part in preedit:gmatch("[^" .. escaped_delimiter .. "]+") do
-                    table.insert(preedits_table, part)
+    -- 懒加载 tone_map
+    if not env.tone_map then
+        env.tone_map = {}
+        local cfg = engine and engine.schema and engine.schema.config
+        if cfg then
+            for d = 0, 9 do
+                local k = tostring(d)
+                local v = cfg:get_string("tone_preedit/" .. k)
+                if v and v ~= "" then
+                    env.tone_map[k] = v
                 end
             end
         end
     end
 
-    local dictEntry = DictEntry()
+    local preedit = cand.preedit
+    local converted = preedit:gsub("([^%d%s]+)(%d+)", function(body, digits)
+        local mapped = digits:gsub("%d", function(d)
+            return env.tone_map and env.tone_map[d] or d
+        end)
+        return body .. mapped
+    end)
 
-    dictEntry.text = commit_text
-    dictEntry.weight = 1
-    dictEntry.custom_code = table.concat(preedits_table, " ") .. " "
-
-    env.memory:update_userdict(dictEntry, 1, "")
-
-    --log.info(string.format("[auto_phrase] 自动造词：[%s]，编码：[%s]", dictEntry.text, dictEntry.custom_code))
-
-    comment_cache = {}
+    if converted ~= preedit then
+        cand.preedit = converted
+    end
 end
 
--- 判断字符是否为汉字
-function AP.is_chinese_only(text)
-    local non_chinese_pattern = "[%w%p]"
 
-    if not text or text == "" then
-        return false
-    end
-
-    if text:match(non_chinese_pattern) then
-        return false
-    end
-
-    for _, cp in utf8.codes(text) do
-        -- 常用汉字区 + 扩展 A/B/C/D/E/F/G
-        if
-            not ((cp >= 0x4E00 and cp <= 0x9FFF) or -- CJK Unified Ideographs
-                (cp >= 0x3400 and cp <= 0x4DBF) or -- CJK Ext-A
-                (cp >= 0x20000 and cp <= 0x2EBEF) or -- CJK Ext-B~G（需 5.3+ 支持大码点）
-                false)
-         then
-            return false
-        end
-    end
-    return true
-end
 -- ----------------------
 -- 主函数：根据优先级处理候选词的注释和preedit
 -- ----------------------
@@ -363,12 +352,12 @@ function ZH.init(env)
         candidate_length = tonumber(config:get_string("super_comment/candidate_length")) or 1,
     }
     CR.init(env)
-    AP.init(env)
+    SV.init(env)
 end
 function ZH.fini(env)
     -- 清理
     CF.fini(env)
-    AP.fini(env)
+    SV.fini(env)
 end
 function ZH.func(input, env)
     local config = env.engine.schema.config
@@ -400,47 +389,9 @@ function ZH.func(input, env)
         local initial_comment = genuine_cand.comment
         local final_comment = initial_comment
         index = index + 1
-        -- auto_phrase 相关处理,只保存comment
-        if enable_auto_phrase and enable_user_dict then 
-            AP.save_comment_cache(cand)
-        end
-        do
-            local ctx = env.engine.context
-            local raw_in = ctx.input or ""
-            if env._saved_input_for_seq ~= raw_in then
-                ctx:set_property("sequence_preedit_key", raw_in)
-                ctx:set_property("sequence_preedit_val", preedit)
-                env._saved_input_for_seq = raw_in
-            end
-        end
-        -- 这里开始：始终进行常规状态下的“数字→声调符号”的 preedit 转换（schema: tone_preedit/0..9）
-        -- 为啥不用系统带的转换：避免转写影响 Lua 拿到的原始 preedit
-        if not env.tone_map then
-            env.tone_map = {}
-            local cfg = env.engine.schema.config
-            for d = 0, 9 do
-                local k = tostring(d)
-                local v = cfg:get_string("tone_preedit/" .. k)
-                if v and v ~= "" then
-                    env.tone_map[k] = v
-                end
-            end
-        end
 
-        if preedit ~= "" then
-            -- 全局：把每个「字母+尾随数字」中的数字逐位映射（不会动分隔符/空格）
-            -- 例： "ni9 zl0 na li" -> "ni³ zl⁴ na li"
-            local converted = preedit:gsub("([%a]+)(%d+)", function(body, digits)
-                local mapped = digits:gsub("%d", function(d)
-                    return env.tone_map[d] or d
-                end)
-                return body .. mapped
-            end)
+        SV.update_preedit(env, preedit) --储存到环境变量
 
-            if converted ~= preedit then
-                genuine_cand.preedit = converted
-            end
-        end
         -- preedit相关处理只跳过 preedit，不影响注释
         if is_radical_mode then
             goto after_preedit
@@ -476,6 +427,7 @@ function ZH.func(input, env)
             for segment in string.gmatch(initial_comment, "[^" .. auto_delimiter .. manual_delimiter .. "]+") do
                 local pinyin = segment:match("^[^;]+")
                 if pinyin then
+                    pinyin = pinyin:gsub("[%[%]]", "")  --去掉英文词库编码中的[]
                     table.insert(pinyin_segments, pinyin)
                 end
             end
@@ -526,11 +478,11 @@ function ZH.func(input, env)
             genuine_cand.preedit = table.concat(input_parts)
         end
         ::after_preedit::
-
         if should_skip_candidate_comment then
             yield(genuine_cand)
             goto continue
         end
+        apply_tone_preedit(env, genuine_cand)
         -- 进入注释处理阶段
         -- ① 辅助码注释或者声调注释
         if is_comment_hint then
@@ -544,7 +496,11 @@ function ZH.func(input, env)
                 final_comment = fz_comment
             end
         else
-            final_comment = ""
+            if initial_comment and string.find(initial_comment, "~") then --保留尾部临时英文标记
+                final_comment = initial_comment
+            else
+                final_comment = ""
+            end
         end
 
         -- ② 拆分注释
@@ -575,6 +531,7 @@ function ZH.func(input, env)
         if final_comment ~= initial_comment then
             genuine_cand.comment = final_comment
         end
+
         yield(genuine_cand)
         ::continue::
     end
